pub enum SessionClosedReason {
ClientClose,
Error,
ServerLost,
}Variants
ClientClose
Client closed the session, the is the normal termination
Error
Sess ends with error
ServerLost
When server starts and reuses existing log, it find open sessions and write this close reason This means that the real closing time of the session is not know and original server probably crashed